Authors
===============================

Development lead
----------------

Juan David Alzate Cardona (jdalzatec@unal.edu.co):
    Graduated student of engineering physics in the National University of
    Colombia, in Manizales.

    Graduated student of Master of Science - Physics in the National University
    of Colombia, in Manizales.

Contributors
--------------

* Luisa Fernanda Velásquez González (lufvelasquezgo@unal.edu.co):
    Current student of engineering physics in the National University of
    Colombia, in Manizales.

* Juan Sebastian Salcedo Gallo (jussalcedoga@unal.edu.co):
    Graduated student of engineering physics in the National University of
    Colombia, in Manizales.

    Current student of Master of Science - Physics in the National University
    of Colombia, in Manizales.

* Daniel Felipe Rodriguez Patiño (dfrodriguezp@unal.edu.co):
    Graduated student of engineering physics in the National University of
    Colombia, in Manizales.

    Current student of Master of Science - Physics in the National University
    of Colombia, in Manizales.
